@@ -245,7 +245,7 @@ class Repo(IInclude):
       lines += ["{% endtabs %}\n"]
       return self.update_link("\n".join(lines))
     lines = []
-    ignored = [".gitignore"] + check_output("git ls-files --other", text=True, shell=True).splitlines()
+    ignored = [".gitignore", "images"] + check_output("git ls-files --other", text=True, shell=True).splitlines()
     for file_glob in self.glob.split("|"):
       lines += ["{% tabs %}"]
       for file in self.path.glob(file_glob):
